@@ -1,13 +1,15 @@
+import datetime
+from pathlib import Path
+
 import nonebot
 from nonebot import require, get_plugin_config
 from nonebot.rule import Rule
 from nonebot.log import logger
-from nonebot.plugin import PluginMetadata
-
+from nonebot.plugin import PluginMetadata, inherit_supported_adapters
 require("nonebot_plugin_alconna")
 require("nonebot_plugin_htmlrender")
 from openai import BadRequestError
-from arclet.alconna import Args, Option, Alconna, MultiVar
+from arclet.alconna import Args, Option, Alconna, MultiVar, CommandMeta
 from nonebot_plugin_alconna import UniMessage, on_alconna, Match
 from nonebot_plugin_htmlrender import md_to_pic
 
@@ -16,6 +18,17 @@ from .GPT_handler import GPTHandler
 from .context_manager import ContextManager
 
 
+__plugin_meta__ = PluginMetadata(
+    name="GitHub Models",
+    description="一个调用 GitHub Models 的 AI 对话插件",
+    usage="/AI Hello",
+    type="application",
+    homepage="https://github.com/lyqgzbl/nonebot-plugin-githubmodels",
+    config=Config,
+    supported_adapters=inherit_supported_adapters("nonebot_plugin_alconna"),
+)
+
+
 plugin_config = get_plugin_config(Config)
 REPLY_IMAGE = plugin_config.ai_reply_image
 
@@ -48,8 +61,14 @@ ai = on_alconna(
     Alconna(
         "AI",
         Args["user_input?", MultiVar(str)],
-        Option("-r|--reset"),
-        Option("-i|--image"),
+        Option("-r|--reset", help_text="重置上下文记忆"),
+        Option("-i|--image", help_text="临时启用图片回复"),
+				meta=CommandMeta(
+            description="AI 对话插件",
+            usage=__plugin_meta__.usage,
+            example="/AI Hello; /AI -i Hello; /AI -r",
+            compact=True,
+        ),
     ),
     rule=is_enable(),
     use_cmd_start=True,
@@ -88,7 +107,12 @@ async def got_location(user_input: str):
         reply = await GPT_handler.get_response(messages)
         context_manager.add_message("assistant", reply)
         if REPLY_IMAGE:
-            pic = await md_to_pic(md=reply)
+            current_hour = datetime.datetime.now().hour
+            is_dark_mode = 18 <= current_hour or current_hour < 6
+            css_file = (
+                Path(__file__).parent / "css" / ("dark.css" if is_dark_mode else "light.css")
+            )
+            pic = await md_to_pic(md=reply, css_path=str(css_file))
             await UniMessage.image(raw=pic).send(reply_to=True)
         else:
             await UniMessage.text(reply).send(reply_to=True)
@@ -96,14 +120,4 @@ async def got_location(user_input: str):
         logger.opt(colors=True).error(f"<red>API 请求失败: {e}</red>")
         await ai.send("问题触发了内容过滤策略,请修改问题后重试")
     finally:
-        REPLY_IMAGE = plugin_config.ai_reply_image
-
-
-__plugin_meta__ = PluginMetadata(
-    name="githubmodels",
-    description="API 调用 GitHub Models 的大语言模型",
-    usage="AI",
-    type="application",
-    homepage="https://github.com/lyqgzbl/nonebot-plugin-githubmodels",
-    supported_adapters=None,
-)
\ No newline at end of file
+        REPLY_IMAGE = plugin_config.ai_reply_image
\ No newline at end of file
